# Copyright (c) 2026 Dedalus Labs, Inc. and its contributors
# SPDX-License-Identifier: MIT

"""OAuth 2.0 Device Authorization Grant (RFC 8628).

DeviceCodeAuth is for CLI tools and devices without browsers.
The user authorizes on a separate device.

TODO: Implement for CLI usage.
"""

from __future__ import annotations


class DeviceCodeAuth:
    """OAuth 2.0 Device Authorization Grant (RFC 8628).

    Not yet implemented.
    """

    def __init__(self) -> None:
        raise NotImplementedError("DeviceCodeAuth is not yet implemented")
